@@ -1,8 +1,9 @@
 #' Study Year
 #'
+#' @inheritParams params
 #' @param x A Date or POSIXct vector.
 #' @param start An integer vector of the starting month or a Date vector of the starting date.
-#' @param full A flag specifying whether to return a character vector of the study years (or an integer vector of the first year)
+#'
 #' @return A character vector of the study year or an integer vector of the first year.
 #' @export
 #'
@@ -10,12 +11,14 @@
 #' dtt_study_year(as.Date(c("2000-03-31", "2000-04-01", "2001-04-01")), start = 4L)
 #' dtt_study_year(as.Date(c("2000-03-31", "2000-04-01", "2001-04-01")), start = 4L, full = FALSE)
 dtt_study_year <- function(x, start = 1L, full = TRUE) {
-  chkor(
-    chk_s3_class(x, "Date"),
-    chk_s3_class(x, "POSIXct")
-  )
+  if (!vld_s3_class(x, "Date") && !vld_s3_class(x, "POSIXct")) {
+    chkor_vld(vld_s3_class(x, "Date"), vld_s3_class(x, "POSIXct"))
+  }
+
+  if (!vld_date(start) && !vld_whole_number(start)) {
+    chkor_vld(vld_date(start), vld_whole_number(start))
+  }
 
-  chkor(chk_date(start), chk_whole_number(start))
   if (vld_whole_number(start)) {
     chk_range(start, c(1L, 12L))
   }
