@@ -1,9 +1,9 @@
 #' Units per Unit
 #'
-#' @param units A string of the time units.
-#' @param unit A string of the time unit.
+#' @inheritParams params
 #'
 #' @return A number of the units per unit
+#' @family units
 #' @export
 #'
 #' @examples
@@ -17,25 +17,29 @@ dtt_units_per_unit <- function(units = "seconds", unit = "days") {
 #' @param x An integer or numeric vector
 #' @param from A string of the original units.
 #' @param to A string of the new units.
-#'
+
 #' @return A numeric vector.
+#' @seealso [dtt_add_units()]
+#' @seealso [dtt_subtract_units()]
+#' @family units
 #' @export
 #'
 #' @examples
 #' dtt_adjust_units(60, to = "minutes")
 dtt_adjust_units <- function(x, from = "seconds", to = "seconds") {
-  chk_whole_numeric(x)
+  chk_numeric(x)
   x * dtt_units_per_unit(to, from)
 }
-
 #' Get Units
 #'
 #' Gets the smallest units for a date time vector.
 #' The possible values are 'seconds', 'minutes', 'hours', 'days', 'months' or 'years'.
 #'
+#' @inheritParams params
 #' @param x A Date, POSIXct or hms vector.
-#' @param ... Unused.
+#'
 #' @return A string indicating the date time units.
+#' @family units
 #' @export
 #'
 #' @examples
